@@ -41,7 +41,10 @@ func syncServiceCatalogControllerManager_v311_00_to_latest(c ServiceCatalogContr
 	errors := []error{}
 	var err error
 	operatorConfig := originalOperatorConfig.DeepCopy()
-	directResourceResults := resourceapply.ApplyDirectly(c.kubeClient, c.recorder, v311_00_assets.Asset,
+
+	// react to API change
+	clientHolder := resourceapply.NewKubeClientHolder(c.kubeClient)
+	directResourceResults := resourceapply.ApplyDirectly(clientHolder, c.recorder, v311_00_assets.Asset,
 		"v3.11.0/openshift-svcat-controller-manager/ns.yaml",
 		"v3.11.0/openshift-svcat-controller-manager/crb-catalog-controller.yaml",
 		"v3.11.0/openshift-svcat-controller-manager/crb-controller-namespace-viewer-binding.yaml",
